DVAssetPackEntry class final

One file going into a pack.

stored is bytes encoded with encoding, when the build encoded it; the pack keeps whichever is smaller. protected marks a file only an authorised caller may be sent, which no cache shared between callers may keep.

Constructors

DVAssetPackEntry(String path, Uint8List bytes, {Uint8List? stored, DVAssetEncoding encoding = DVAssetEncoding.identity, bool protected = false})

Properties

bytes → Uint8List
final
encoding → DVAssetEncoding
final
hashCode → int
The hash code for this object.
no setterinherited
path → String
final
protected → bool
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
stored → Uint8List?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited