DVPackedAsset class final

A file in an opened pack.

Properties

encoding → DVAssetEncoding
How it is stored.
final
hash → String
The first 128 bits of the SHA-256 of its content, in hex: the same for the same bytes in every build, whatever they are stored as.
final
hashCode → int
The hash code for this object.
no setterinherited
path → String
Its path, relative to the root it was packed from, with /.
final
protected → bool
Whether only an authorised caller may be sent it.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size → int
How many bytes it is.
final
storedLength → int
How many bytes it is stored as.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited