hash property
The first 128 bits of the SHA-256 of its content, in hex: the same for the same bytes in every build, whatever they are stored as.
Implementation
final String hash;
The first 128 bits of the SHA-256 of its content, in hex: the same for the same bytes in every build, whatever they are stored as.
final String hash;