installUrl property
A page testers open on a device to install a development or preview build, when the service offers one.
Implementation
final String? installUrl;
A page testers open on a device to install a development or preview build, when the service offers one.
final String? installUrl;