workerOs property
DVCloudWorkerOs
get
workerOs
The operating system of the worker that builds this.
Implementation
DVCloudWorkerOs get workerOs => os ?? dvCloudWorkerOs(target)!;
The operating system of the worker that builds this.
DVCloudWorkerOs get workerOs => os ?? dvCloudWorkerOs(target)!;