DVCloudEvent class

One event on a build's stream: a line of its log, or a change of status.

Constructors

DVCloudEvent.log(int id, String line)
const
DVCloudEvent.status(int id, DVCloudBuildStatus status)
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
id → int
Increasing per build; sent back as Last-Event-ID to resume.
final
line → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → DVCloudBuildStatus?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited