Body class

Constructors

Body(Stream<List<int>> stream)

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stream Stream<List<int>>
no setter

Methods

bytes() Future<List<int>>
bytesU8() Future<Uint8List>
jsonDecode([Encoding enc = utf8]) Future
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
text([Encoding enc = utf8]) Future<String>
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited