Headers class

Constructors

Headers([Map<String, dynamic>? init])

Properties

hashCode int
The hash code for this object.
no setterinherited
multiValueMap Map<String, List<String>>
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
singleValueMap Map<String, String>
no setter

Methods

append(String name, String value) → void
delete(String name) → void
get(String name) String?
getAll(String name) Iterable<String>
has(String name) bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
set(String name, String value) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited