Router class
Constructors
- Router()
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
any(
String pattern, Handler h) → Router -
call(
Request req) → Future< Response> -
delete(
String pattern, Handler h) → Router -
get(
String pattern, Handler h) → Router -
head(
String pattern, Handler h) → Router -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
post(
String pattern, Handler h) → Router -
put(
String pattern, Handler h) → Router -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited