id property
String
get
id
The name Studio lists and addresses the model by.
Implementation
String get id => module == null ? model : '$module.$model';
The name Studio lists and addresses the model by.
String get id => module == null ? model : '$module.$model';