DVAssetEncoding enum

How a file's bytes are kept, and the Content-Encoding that names them.

Inheritance
Available extensions

Values

identity → const DVAssetEncoding
const DVAssetEncoding('identity')
br → const DVAssetEncoding
const DVAssetEncoding('br')
zstd → const DVAssetEncoding
const DVAssetEncoding('zstd')
gzip → const DVAssetEncoding
const DVAssetEncoding('gzip')

Properties

hashCode → int
The hash code for this object.
no setterinherited
index → int
A numeric identifier for the enumerated value.
no setterinherited
name → String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → String
The Content-Encoding / Accept-Encoding token.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

values → const List<DVAssetEncoding>
A constant List of the values in this enum, in order of their declaration.