protected property
bool
get
protected
Whether only an authorised caller may be sent it. Never kept by a cache shared between callers.
Implementation
bool get protected;
Whether only an authorised caller may be sent it. Never kept by a cache shared between callers.
bool get protected;