stored abstract method
Its bytes as kept, or the part from start to end: what a client that
accepts storedEncoding is sent as it is.
Implementation
Uint8List stored({int start = 0, int? end});
Its bytes as kept, or the part from start to end: what a client that
accepts storedEncoding is sent as it is.
Uint8List stored({int start = 0, int? end});