storedEncoding property
DVAssetEncoding
get
storedEncoding
How it is kept, and so what stored returns.
Implementation
DVAssetEncoding get storedEncoding;
How it is kept, and so what stored returns.
DVAssetEncoding get storedEncoding;