maxAge property
Seconds a browser may keep a file whose name is not hashed without asking again. Null: it asks every time.
Implementation
final int? maxAge;
Seconds a browser may keep a file whose name is not hashed without asking again. Null: it asks every time.
final int? maxAge;