register static method
Serves root from source rather than from a directory of that name.
Implementation
static void register(String root, DVAssetSource source) => _registered[root] = source;
Serves root from source rather than from a directory of that name.
static void register(String root, DVAssetSource source) => _registered[root] = source;