lease property
How long a publisher may hold a range of sequences before another process treats it as dead and moves past it.
Implementation
final Duration lease;
How long a publisher may hold a range of sequences before another process treats it as dead and moves past it.
final Duration lease;