retention property
How long a published change is kept. Bounded and declared: a consumer
further behind than this is told to backfill (DV-CDC-002).
Implementation
final Duration retention;
How long a published change is kept. Bounded and declared: a consumer
further behind than this is told to backfill (DV-CDC-002).
final Duration retention;