strandedAfter property

Duration strandedAfter
final

How old a staged change must be before publishStranded treats the transaction that staged it as gone.

Implementation

final Duration strandedAfter;