unconfigure static method

void unconfigure()

Forgets the configured log. A captured model then records to a log in the configured database, as a process the server did not start does.

Implementation

static void unconfigure() => _configured = null;