codecName constant
String
const codecName
What a queue shared between processes stores the job under.
Implementation
static const String codecName = 'dartvel.capture.backfill';
What a queue shared between processes stores the job under.
static const String codecName = 'dartvel.capture.backfill';