DVCaptureBehindRetentionError class
DV-CDC-002: a consumer is behind the retention window and must backfill.
- Implemented types
Constructors
- DVCaptureBehindRetentionError({required String consumer, required int checkpoint, required int prunedThrough})
Properties
- checkpoint → int
-
final
- code → String
-
final
- consumer → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- prunedThrough → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited