DVCaptureConfigError class

DV-CDC-006, DV-CDC-007 or DV-CDC-008: dartvel.capture says something the framework cannot do.

Implemented types

Constructors

DVCaptureConfigError(String code, String message)
const

Properties

code → String
final
hashCode → int
The hash code for this object.
no setterinherited
message → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited