DVCaptureDeliveryError class

DV-CDC-001: a destination refused a batch; delivery is retrying.

Implemented types

Constructors

DVCaptureDeliveryError({required String consumer, required String sink, required int checkpoint, required Object cause})

Properties

cause → Object
final
checkpoint → int
Where the consumer still stands.
final
code → String
final
consumer → String
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
sink → String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited