DVCaptureLag class
How far a consumer is behind what has been captured.
Constructors
-
DVCaptureLag({required int changes, required Duration age, List<
String> codes = const <String>[]})
Properties
- age → Duration
-
How long ago the oldest undelivered change happened: how stale the
destination is. Zero when caught up.
final
- changes → int
-
Captured changes not yet delivered.
final
-
codes
→ List<
String> -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited