erase method
Implementation
@override
Future<void> erase(DVPrivacySubjectRef subject) async {
throw StateError(
'$name erases the records an erasure reached, and was not told which; '
'DVPrivacy passes them through eraseRecords.',
);
}
@override
Future<void> erase(DVPrivacySubjectRef subject) async {
throw StateError(
'$name erases the records an erasure reached, and was not told which; '
'DVPrivacy passes them through eraseRecords.',
);
}