backoff constant
Duration
const backoff
How long the queue waits before trying a refused delivery again.
Implementation
static const Duration backoff = Duration(seconds: 30);
How long the queue waits before trying a refused delivery again.
static const Duration backoff = Duration(seconds: 30);