log property
DVCapture?
get
log
The log this process writes to, or null when none is configured.
Implementation
static DVCapture? get log => _runtime?.log;
The log this process writes to, or null when none is configured.
static DVCapture? get log => _runtime?.log;