pruneEvery constant
Duration
const pruneEvery
How often the log is pruned to its retention.
Implementation
static const Duration pruneEvery = Duration(hours: 1);
How often the log is pruned to its retention.
static const Duration pruneEvery = Duration(hours: 1);