erase abstract method
Applies an erasure now, out of band, superseding every change to the same records with a lower sequence -- including one already in flight.
Implementation
Future<void> erase(List<DVCapturedChange> changes);
Applies an erasure now, out of band, superseding every change to the same records with a lower sequence -- including one already in flight.
Future<void> erase(List<DVCapturedChange> changes);