evolve abstract method
Adds or removes columns. Must be idempotent: a crash after it and before the checkpoint delivers it again.
Implementation
Future<void> evolve(DVCaptureSchemaChange change);
Adds or removes columns. Must be idempotent: a crash after it and before the checkpoint delivers it again.
Future<void> evolve(DVCaptureSchemaChange change);