write abstract method
Applies batch. Throwing leaves the checkpoint where it was, and the
whole batch is delivered again (DV-CDC-001).
Implementation
Future<void> write(DVCaptureBatch batch);
Applies batch. Throwing leaves the checkpoint where it was, and the
whole batch is delivered again (DV-CDC-001).
Future<void> write(DVCaptureBatch batch);