erased property
Whether this change is an erasure, which supersedes every earlier change to the record however it arrives.
Implementation
final bool erased;
Whether this change is an erasure, which supersedes every earlier change to the record however it arrives.
final bool erased;