version property
The record's version after this change. Two changes to one record that committed out of order still compare correctly on it.
Implementation
final int version;
The record's version after this change. Two changes to one record that committed out of order still compare correctly on it.
final int version;