correctedTime property
deviceTime corrected by the offset the device last observed from the server. This is the stamp a declared clock compares.
Implementation
final DateTime correctedTime;
deviceTime corrected by the offset the device last observed from the server. This is the stamp a declared clock compares.
final DateTime correctedTime;