path constant
String
const path
The route the generated backend serves this on, under the API base path.
Implementation
static const String path = '/offline/replay';
The route the generated backend serves this on, under the API base path.
static const String path = '/offline/replay';