DVOfflineReply class

What the replay route answered: its status and its JSON body.

Constructors

DVOfflineReply(int status, [Map<String, Object?>? body])
const

Properties

body → Map<String, Object?>?
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
status → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited