value property
Bound as a parameter, and compared with =: a null value matches no
row, as SQL has it, rather than every row with no tenant.
Implementation
final Object? value;
Bound as a parameter, and compared with =: a null value matches no
row, as SQL has it, rather than every row with no tenant.
final Object? value;