capture property
The change capture log every write is recorded to, or null when the model is not captured. Sensitive fields are left out of it.
Implementation
final DVCapture? capture;
The change capture log every write is recorded to, or null when the model is not captured. Sensitive fields are left out of it.
final DVCapture? capture;