appliedTable property
String
get
appliedTable
Mutation ids already applied, and what came of each.
Implementation
String get appliedTable => '${table.table}__applied';
Mutation ids already applied, and what came of each.
String get appliedTable => '${table.table}__applied';