clockTable property
String
get
clockTable
The declared clock of the last write that landed on each record.
Implementation
String get clockTable => '${table.table}__clock';
The declared clock of the last write that landed on each record.
String get clockTable => '${table.table}__clock';