conflicted property
Accepted mutations the server resolved into something other than what the device wrote.
Implementation
final int conflicted;
Accepted mutations the server resolved into something other than what the device wrote.
final int conflicted;