DVAssetPackEntry class final
One file going into a pack.
stored is bytes encoded with encoding, when the build encoded it; the pack keeps whichever is smaller. protected marks a file only an authorised caller may be sent, which no cache shared between callers may keep.
Constructors
- DVAssetPackEntry(String path, Uint8List bytes, {Uint8List? stored, DVAssetEncoding encoding = DVAssetEncoding.identity, bool protected = false})
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited