dvCloudArtifactLinkHeader top-level constant

String const dvCloudArtifactLinkHeader

Sent with an artifact a worker uploads, with an empty body: the artifact is a symbolic link to this target.

Implementation

const String dvCloudArtifactLinkHeader = 'X-Dartvel-Artifact-Link';