DVWorkerTasks class final
Tasks a web worker can be asked to run, by name.
The page and the worker script each register the same names. The page looks a function up to find the name to send; the worker looks the name up to find the function. Top-level and static tear-offs are canonical, so the function itself is a reliable key on both.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited