The decoders a process has. gzip is dart:io's; brotli and zstd come from the native server library, which registers them when it is loaded.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decoder(
DVAssetEncoding encoding) → DVAssetDecoder? -
The decoder for
encoding, or null when this process has none. -
register(
DVAssetEncoding encoding, DVAssetDecoder decoder) → void -
Makes
encodingdecodable in this process.