diskCache property
Whether a file the server has had to decode is kept on disk, beside its data, for the next client that needs it decoded.
Implementation
final bool diskCache;
Whether a file the server has had to decode is kept on disk, beside its data, for the next client that needs it decoded.
final bool diskCache;