The sources this process serves from, by root.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
at(
String root) → DVAssetSource -
The source for
root: what was registered for it or for a directory it is under, or the directory itself. -
clear(
) → void - Forgets every registration.
-
register(
String root, DVAssetSource source) → void -
Serves
rootfromsourcerather than from a directory of that name.