strandedAfter property
How old a staged change must be before publishStranded treats the transaction that staged it as gone.
Implementation
final Duration strandedAfter;
How old a staged change must be before publishStranded treats the transaction that staged it as gone.
final Duration strandedAfter;