DVCaptureBackfillJob class
The job that copies one chunk of a model's rows to a consumer, and queues the next until the copy is done.
Constructors
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Methods
-
decode(
Map< String, Object?> json) → DVCaptureBackfillJob -
encode(
DVCaptureBackfillJob job) → Map< String, Object?>