connection property
The name of the secret holding the connection -- read through
DV.Secrets when the server starts, never written into the pubspec.
Implementation
final String connection;
The name of the secret holding the connection -- read through
DV.Secrets when the server starts, never written into the pubspec.
final String connection;