DVRecord class
A stored record: its values, the version they are at, and whether it is soft-deleted.
Constructors
Properties
- deletedAt → DateTime?
-
When the record was soft-deleted, or null when it is live.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Object
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
-
values
→ Map<
String, Object?> -
final
- version → int
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
override
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited