DVWriteResult class
The outcome of a write.
Constructors
- DVWriteResult(DVRecord record, {DVConflictError? conflict, bool discarded = false, bool inserted = false})
-
const
Properties
- conflict → DVConflictError?
-
The conflict a strategy resolved, or null when there was none.
final
- discarded → bool
-
Whether the local change was discarded, as DVConflict.serverWins does.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- inserted → bool
-
Whether the write created the record rather than updating one.
final
- record → DVRecord
-
The record as stored after the write.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited